summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/KoGuideLineDia.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficeui/KoGuideLineDia.h')
-rw-r--r--lib/kofficeui/KoGuideLineDia.h19
1 files changed, 10 insertions, 9 deletions
diff --git a/lib/kofficeui/KoGuideLineDia.h b/lib/kofficeui/KoGuideLineDia.h
index 8545f35d..7dc9e0f8 100644
--- a/lib/kofficeui/KoGuideLineDia.h
+++ b/lib/kofficeui/KoGuideLineDia.h
@@ -29,7 +29,7 @@
class KoUnitDoubleSpinBox;
-class QRadioButton;
+class TQRadioButton;
/**
* @brief Class for setting a guide line position.
@@ -37,18 +37,19 @@ class QRadioButton;
class KoGuideLineDia : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* @brief Constructor
*
* @param parent The parent widget
* @param pos the actual position of the guide line
* @param minPos the minimal position of the guide line
* @param maxPos the maximal position of the guide line
* @param unit The unit used in the document
- * @param name The name is send to the QObject constructor
+ * @param name The name is send to the TQObject constructor
*/
- KoGuideLineDia( QWidget *parent, double pos, double minPos, double maxPos,
+ KoGuideLineDia( TQWidget *tqparent, double pos, double minPos, double maxPos,
KoUnit::Unit unit, const char *name = 0L );
/**
@@ -58,13 +59,13 @@ public:
* and the orientation of the guide line is changed the value will be set to pos.x()
* or pos.y() according to the orientation.
*
* @param parent the parent widget
* @param pos the actual position of cursor
* @param rect the rect in where the guide can be placed
* @param unit the unit used in the document
- * @param name the name is send to the QObject constructor
+ * @param name the name is send to the TQObject constructor
*/
- KoGuideLineDia( QWidget *parent, KoPoint &pos, KoRect &rect,
+ KoGuideLineDia( TQWidget *tqparent, KoPoint &pos, KoRect &rect,
KoUnit::Unit unit, const char *name = 0L );
/**
* @brief the position
@@ -88,8 +89,8 @@ protected:
KoRect m_rect;
KoPoint m_pos;
bool m_positionChanged;
- QRadioButton * m_hButton;
- QRadioButton * m_vButton;
+ TQRadioButton * m_hButton;
+ TQRadioButton * m_vButton;
KoUnitDoubleSpinBox* m_position;
};
@@ -37,18 +37,19 @@ class QRadioButton;
* @brief Constructor
*
- * @param parent The parent widget
+ * @param tqparent The tqparent widget
* @param pos the actual position of the guide line
* @param minPos the minimal position of the guide line
@@ -58,13 +59,13 @@ public:
* or pos.y() according to the orientation.
*
- * @param parent the parent widget
+ * @param tqparent the tqparent widget
* @param pos the actual position of cursor
* @param rect the rect in where the guide can be placed